import React from 'react';
import type { Metadata } from 'next';
import { getTranslations } from 'next-intl/server';
import { getFilter } from '../../../utils/filter';
import { getExpertsList } from '../../../actions/experts';
import { getTagList } from '../../../actions/tags';
import { Experts } from '../../../components/Experts/Experts';

export const metadata: Metadata = {
    title: 'Bbuddy - Experts',
    description: 'Bbuddy desc experts'
};

export default async function ExpertsPage({ params, searchParams }: { params: { locale: string }, searchParams: { [key: string]: string | string[] | undefined } }) {
    const searchData = await getTagList(params.locale);
    const filter = getFilter(searchData, searchParams);
    console.log('filter experts page', filter);
    const experts = await getExpertsList(filter, params.locale);
    const t = await getTranslations('Experts');

    return (
        <div className="page-search">
            <div className="main-find">
                <div className="b-inner">
                    <div className="main-find__top">
                        <h2 className="title-h2">{t('title')}</h2>
                        <div className="open-filter">
                            <img src="/images/options-outline.svg" alt="" />
                        </div>
                    </div>
                    <Experts
                        experts={experts}
                        searchData={searchData}
                    />
                </div>
            </div>
        </div>
    );
};
