'use client';

import React, { useCallback, useState } from 'react';
import {Button, Select} from 'antd';
import { useSearchParams } from 'next/navigation';
import { useRouter } from '../../navigation';
import { AdditionalFilter } from '../../types/experts';
import { LOCALES } from '../../constants/locale';
import { getObjectByFilter, getObjectByAdditionalFilter } from '../../utils/filter';
import { CustomInput } from '../view';

type ExpertAdditionalFilterProps = {
    searchPlaceholder: string;
    sortLabel: string;
    langLabel: string;
    buttonFind: string;
    basePath?: string;
};

export const ExpertsAdditionalFilter = ({
    searchPlaceholder,
    sortLabel,
    langLabel,
    buttonFind,
    basePath = '/',
}): ExpertAdditionalFilterProps => {
    const searchParams = useSearchParams();
    const router = useRouter();
    const [filter, setFilter] = useState<AdditionalFilter | undefined>(getObjectByAdditionalFilter(searchParams));

    const onChangeFilter = useCallback((key: string, value: any) => {
        // setFilter({
        //     ...filter,
        //     [key]: value
        // })
    }, [filter]);

    const goToFilterPage = useCallback(() => {
        router.push({
            pathname: basePath,
            query: {
                ...getObjectByFilter(searchParams),
                ...filter
            }
        })
    }, [filter, searchParams]);

    return (
        <div className="main-find__search">
            <div className="main-find__search__input">
                <CustomInput
                    placeholder={searchPlaceholder}
                    defaultValue={filter?.text}
                    onChange={(e: any) => onChangeFilter('text', e?.target?.value)}
                />
            </div>
            <div className="main-find__search__sort">
                <Select
                    defaultValue={filter?.sort}
                    onChange={(val) => onChangeFilter('sort', val)}
                    options={[
                        { value: 'byTop', label: 'By top views' },
                        { value: 'byPriceAsc', label: 'By price ascending' },
                        { value: 'byPriceDesc', label: 'By price descending' },
                        { value: 'byRating', label: 'By rating' }
                    ]}
                />
            </div>
            <div className="main-find__search__language">
                <Select
                    mode="multiple"
                    defaultValue={filter?.language}
                    onChange={(val) => onChangeFilter('language', val)}
                    options={Object.entries(LOCALES).map(([ value, label ]) => ({ value, label }))}
                />
            </div>
            <Button
                className="btn-apply"
                onClick={goToFilterPage}
            >
                {buttonFind}
            </Button>
        </div>
    );
};
