import React from 'react';
import { useTranslations } from 'next-intl';
import { SearchData } from '../../types/tags';
import { ExpertsData } from '../../types/experts';
import { ExpertsFilter } from './Filter';
import { ExpertsAdditionalFilter } from './AdditionalFilter';
import { ExpertsList } from './ExpertsList';
import { CustomPagination } from '../view/CustomPagination';

type ExpertsProps = {
    searchData?: SearchData;
    experts?: ExpertsData;
};

export const Experts = ({ searchData, experts }: ExpertsProps) => {
    const t = useTranslations('Experts');

    return (
        <div className="row">
            <div className="col-xl-3 col-lg-4 d-none d-lg-block">
                <ExpertsFilter
                    searchData={searchData}
                    basePath="/experts"
                    priceTitle={t('filter.price', { from: searchData.sessionCostMin, to: searchData.sessionCostMax })}
                    durationTitle={t('filter.duration', { from: searchData.sessionDurationMin, to: searchData.sessionDurationMax })}
                    buttonApply={t('filter.apply')}
                />
            </div>
            <div className="col-xl-9 col-lg-8 ">
                <ExpertsAdditionalFilter
                    searchPlaceholder={t('filter.search')}
                    sortLabel={t('filter.sort')}
                    langLabel={t('filter.language')}
                    buttonFind={t('filter.find')}
                    basePath="/experts"
                />
                <ExpertsList
                    data={experts}
                    priceTitle={t('list.price')}
                    durationTitle={t('list.duration')}
                    detailButton={t('list.details')}
                />
                <CustomPagination total={20} />
            </div>
        </div>
    )
};
